@@ -1612,7 +1612,7 @@ void BookWindow::ScrollToTopSlot()
 Item* BookWindow::CreateItem(QString name, bool special)
 {
     if (!name.isEmpty()){
-        Item* i = new Item(this);
+        Item* i = new Item(m_Player);
         i->Name = name;
         i->SetIsSpecial(special);
         return i;
@@ -1620,6 +1620,17 @@ Item* BookWindow::CreateItem(QString name, bool special)
     return NULL;
 }
 
+Weapon* BookWindow::CreateWeapon(QString name, QString classname)
+{
+    if (!name.isEmpty() && !classname.isEmpty()){
+        Weapon* w = new Weapon(m_Player);
+        w->Name = name;
+        w->AddClass(Weapon::GetClass(classname));
+        return w;
+    }
+    return NULL;
+}
+
 void BookWindow::AddItemToPlayer(Item* item, bool mandatory)
 {
     if (!item)
@@ -1633,7 +1644,7 @@ void BookWindow::AddItemToPlayer(Item* item, bool mandatory)
         if (item->GetIsSpecial())
             i = ChooseItem(ChooseItemWindow::ChooseSpecialItem, message.append(" special item."), mandatory);
         else if (item->GetIsWeapon())
-            i = ChooseItem(ChooseItemWindow::ChooseWeaponSpecial, message.append(" weapon."), mandatory);
+            i = ChooseItem(ChooseItemWindow::ChooseWeapon, message.append(" weapon."), mandatory);
         else
             i = ChooseItem(ChooseItemWindow::ChooseItem, message.append(" backpack item."), mandatory);
 
