@@ -164,6 +164,9 @@ public slots:
     void AddItemToPlayer(Item* item, bool mandatory=false);
     /** Returns a new item*/
     Item* CreateItem(QString name, bool special);
+    /** Returns a new weapon*/
+    Weapon* CreateWeapon(QString name, QString classname);
+
 
     /** Play the "Cartwheel" game (book 2) */
     void PlayCartwheel();
