@@ -161,6 +161,11 @@ Item* Section::AddItem(QString name, bool special)
     return NULL;
 }
 
+void Section::AddItem(Item* item)
+{
+    Items.append(item);
+}
+
 void Section::CopyItemsToSection(int section)
 {
     Book* book = GetBook();
@@ -465,8 +470,8 @@ Item* Book::ParseItem(Section* section, QXmlStreamReader* reader)
     i->SetSize(attrs.value("size").toString().toInt());
     if (i->GetSize() == 0)
         i->SetSize(1);
-    if (i->GetEnduranceRestore() && i->Description.isEmpty())
-        i->Description = QString("Restores %1 ENDURANCE POINTS").arg(i->GetEnduranceRestore());
+
+    i->SetUsability(attrs.value("usability").toString().toInt());
 
     while(!reader->atEnd() &&
           !reader->hasError()) {
@@ -503,9 +508,8 @@ ShopItem* Book::ParseShopItem(Section* section, QXmlStreamReader* reader)
     i->SetSize(attrs.value("size").toString().toInt());
     if (i->GetSize() == 0)
         i->SetSize(1);
-    if (i->GetEnduranceRestore() && i->Description.isEmpty())
-        i->Description = QString("Restores %1 ENDURANCE POINTS").arg(i->GetEnduranceRestore());
 
+    i->SetUsability(attrs.value("usability").toString().toInt());
     i->UnlimitedQuantity = attrs.value("unlimitedquantity").toString().toInt() == 1;
 
     i->Price = attrs.value("price").toString().toInt();
