@@ -5,6 +5,10 @@
 #include <QHash>
 #include <QScriptEngine>
 
+//!  Describes a generic item with properties
+/*!
+
+*/
 class PropertiesItem : public QObject
 {
     Q_OBJECT
@@ -16,11 +20,20 @@ public:
     QHash<QString, QString> Properties;
 
 public slots:
+    /** Returns true if the item has the given property */
     bool HasProperty(QString name) { return Properties.contains(name); }
+    /** Returns the given property (string)*/
     QString GetProperty(QString name);
+    /** Sets the given property (string)*/
     void SetProperty(QString name, QString value);
+    /** Returns the given property (boolean)*/
     bool GetBoolProperty(QString name) { return GetProperty(name).toInt() == 1;}
+    /** Sets the given property (boolean)*/
     void SetBoolProperty(QString name, bool value) { SetProperty(name, value ? "1" : "0"); }
+    /** Returns the given property (integer)*/
+    int GetIntProperty(QString name);
+    /** Sets the given property (boolean)*/
+    void SetIntProperty(QString name, int value) { SetProperty(name, QString::number(value)); }
 };
 
 
@@ -43,6 +56,11 @@ public:
 
     QList<int> GetWeaponClasses();
 
+    /** Returns the sell price of the item */
+    int GetSellPrice() { return GetIntProperty("sys_SellPrice"); }
+    /** Sers the number of times the item can be used */
+    void SetSellPrice(int value) { SetIntProperty("sys_SellPrice", value); }
+
 public slots:
     /** Returns the item name */
     QString GetName() { return Name; }
@@ -71,9 +89,9 @@ public slots:
     void SetIsQuiver(bool value) { SetBoolProperty("IsQuiver", value); }
 
     /** Returns the number of arrows the item contains */
-    int GetArrows() { return GetProperty("Arrows").toInt(); }
+    int GetArrows() { return GetIntProperty("Arrows"); }
     /** Sets the number of arrows the item contains */
-    void SetArrows(int value) { SetProperty("Arrows", QString::number(value)); }
+    void SetArrows(int value) { SetIntProperty("Arrows", value); }
 
     /** Returns true if the item is a meal */
     bool GetIsMeal() { return GetBoolProperty("IsMeal"); }
@@ -81,14 +99,14 @@ public slots:
     void SetIsMeal(bool value) { SetBoolProperty("IsMeal", value); }
 
     /** Returns the endurance points restored by the item when used */
-    int GetEnduranceRestore() { return GetProperty("EnduranceRestore").toInt(); }
+    int GetEnduranceRestore() { return GetIntProperty("EnduranceRestore"); }
     /** Sets the endurance points restored by the item when used */
-    void SetEnduranceRestore(int value) { SetProperty("EnduranceRestore", QString::number(value)); }
+    void SetEnduranceRestore(int value) { SetIntProperty("EnduranceRestore", value); }
 
     /** Returns the endurance points bonus when equipped */
-    int GetEnduranceDelta() { return GetProperty("EnduranceDelta").toInt(); }
+    int GetEnduranceDelta() { return GetIntProperty("EnduranceDelta"); }
     /** Sets the endurance points bonus when equipped */
-    void SetEnduranceDelta(int value) { SetProperty("EnduranceDelta", QString::number(value)); }
+    void SetEnduranceDelta(int value) { SetIntProperty("EnduranceDelta", value); }
 
     /** Returns the item description */
     QString GetDescription();
@@ -96,19 +114,19 @@ public slots:
     void SetDescription(QString value) { Description = value; }
 
     /** Returns the combat skill bonus when equipped */
-    int GetCombatskillDelta() { return GetProperty("CombatskillDelta").toInt(); }
+    int GetCombatskillDelta() { return GetIntProperty("CombatskillDelta"); }
     /** Sets the combat skill bonus when equipped */
-    void SetCombatskillDelta(int value) { SetProperty("CombatskillDelta", QString::number(value)); }
+    void SetCombatskillDelta(int value) { SetIntProperty("CombatskillDelta", value); }
 
     /** Returns the item quantity */
-    int GetQuantity() { return GetProperty("Quantity").toInt(); }
+    int GetQuantity() { return GetIntProperty("Quantity"); }
     /** Sets the item quantity */
-    void SetQuantity(int value) { SetProperty("Quantity", QString::number(value)); }
+    void SetQuantity(int value) { SetIntProperty("Quantity", value); }
 
     /** Returns the item size (space used in the backpack) */
-    int GetSize() { return GetProperty("Size").toInt(); }
+    int GetSize() { return GetIntProperty("Size"); }
     /** Sets the item size (space used in the backpack) */
-    void SetSize(int value) { SetProperty("Size", QString::number(value)); }
+    void SetSize(int value) { SetIntProperty("Size", value); }
     /** Returns the total item size (space used in the backpack) */
     int GetTotalSize();
 
@@ -152,28 +170,37 @@ public slots:
     void SetIsArmor(bool value) { SetBoolProperty("IsArmor", value); }
 
     /** Returns the armor class */
-    int GetArmorClass() { return GetProperty("ArmorClass").toInt(); }
+    int GetArmorClass() { return GetIntProperty("ArmorClass"); }
     /** Sets the armor class */
-    void SetArmorClass(int value) { SetProperty("ArmorClass", QString::number(value)); }
+    void SetArmorClass(int value) { SetIntProperty("ArmorClass", value); }
     /** Sets the armor class */
     void SetArmorClass(QString value);
 
     /** Returns the hands needed to equip the item */
-    int GetHands() { return GetProperty("Hands").toInt(); }
+    int GetHands() { return GetIntProperty("Hands"); }
     /** Sets the hands needed to equip the item */
-    void SetHands(int value) { SetProperty("Hands", QString::number(value)); }
+    void SetHands(int value) { SetIntProperty("Hands", value); }
 
     /** Returns the bonus the item gives when picking a random number */
-    int GetRandomBonus() { return GetProperty("RandomBonus").toInt(); }
+    int GetRandomBonus() { return GetIntProperty("RandomBonus"); }
     /** Sets the bonus the item gives when picking a random number */
-    void SetRandomBonus(int value) { SetProperty("RandomBonus", QString::number(value)); }
+    void SetRandomBonus(int value) { SetIntProperty("RandomBonus", value); }
+
+    /** Returns the number of times the item can be used */
+    int GetUsability() { return GetIntProperty("sys_Usability"); }
+    /** Sers the number of times the item can be used */
+    void SetUsability(int value) { SetIntProperty("sys_Usability", value); }
+
+    /** Returns true if the item can be dropped */
+    bool GetCanBeDropped();
+    /** Sets if the item can be dropped */
+    void SetCanBeDropped(bool value) { SetBoolProperty("sys_CanBeDropped", value); }
 };
 
 //!  Describes a weapon
 /*!
 
 */
-
 class Weapon : public Item
 {
     Q_OBJECT
