@@ -731,11 +731,13 @@ void Player::SetHasBackpack(bool value)
 {
     m_Backpack = value;
     if (!m_Backpack){
-        QList<Item*>::iterator iterator;
-        for (iterator = Items.begin(); iterator != Items.end(); ++iterator){
+        QList<Item*>::iterator iterator = Items.begin();
+        while (iterator != Items.end()) {
             Item* i = *iterator;
             if (i->GetIsBackpackItem())
-                Items.erase(iterator);
+                iterator = Items.erase(iterator);
+            else
+                iterator++;
         }
     }
 }
