@@ -49,7 +49,6 @@ FightWindow::FightWindow(QWidget *parent, Player* player, Enemy* enemy, bool can
     m_Player = player;
     m_Enemy = enemy;
 
-    m_LastRandomNumber = 0;
     m_RandomPicker = new RandomNumberPicker(this, ui->lblDice, false);
     connect(m_RandomPicker, SIGNAL(Random(int)), SLOT(RandomSlot(int)));
 
@@ -121,12 +120,17 @@ void FightWindow::UpdateData()
             }
 
             ui->cmbDiscipline->addItems(items);
-            if (psiSurge->GetIsActive())
+            if (psiSurge->GetIsActive()){
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("Psi-surge"));
-            else if (mindBlast->GetIsActive())
+                mindBlast->SetIsActive(false);
+            }else if (mindBlast->GetIsActive()){
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("Mindblast"));
-            else if (items.contains("None"))
+                psiSurge->SetIsActive(false);
+            }else if (items.contains("None")){
                 ui->cmbDiscipline->setCurrentIndex(items.indexOf("None"));
+                psiSurge->SetIsActive(false);
+                mindBlast->SetIsActive(false);
+            }
         }
     }else{
         ui->lblDiscipline->setVisible(false);
@@ -206,7 +210,6 @@ void FightWindow::Evaluate(int number)
     if (number == 0 || number > 10)
         number = 10;
 
-    m_LastRandomNumber = number;
     int ratio = m_Player->GetCombatSkill(m_Enemy) - m_Enemy->CombatSkill;
 
     if (ratio > 11)
@@ -349,7 +352,7 @@ int FightWindow::GetRound()
 
 int FightWindow::GetLastRandomNumber()
 {
-    return m_LastRandomNumber;
+    return m_RandomPicker->GetLastRandomNumber();
 }
 
 int FightWindow::GetLostEndurancePoints()
