@@ -60,15 +60,17 @@ void MainWindow::LoadSlot()
 #endif
 
     BookWindow* w = new BookWindow(this);
-    w->Init();
-
+    if (w->Init()){
 #ifndef Q_WS_MAEMO_5
 #if defined(Q_OS_WIN) || defined(Q_OS_WINCE) || defined(Q_OS_LINUX) || defined (Q_OS_MACX)
-    setVisible(false);
-    connect(w, SIGNAL(destroyed()), this, SLOT(BookwindowClosedSlot()));
-    w->setParent(NULL);
+        setVisible(false);
+        connect(w, SIGNAL(destroyed()), this, SLOT(BookwindowClosedSlot()));
+        w->setParent(NULL);
 #endif
 #endif
+        w->show();
+    }
+
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
@@ -80,7 +82,6 @@ void MainWindow::LoadSlot()
     ui->pbnSettings->setEnabled(true);
     ui->pbnQuit->setEnabled(true);
 #endif
-    w->show();
 }
 
 void MainWindow::AboutSlot()
