@@ -1,8 +1,5 @@
 #include "playercreationwindow.h"
 #include "ui_playercreationwindow.h"
-#ifdef Q_WS_MAEMO_5
-#include <QMaemo5Style>
-#endif
 #include "commonstatic.h"
 #include "ruleswindow.h"
 #include "core/books.h"
@@ -23,10 +20,7 @@ PlayerCreationWindow::PlayerCreationWindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5AutoOrientation);
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    QColor secondaryColor = QMaemo5Style::standardColor("SecondaryTextColor");
-    QPalette secondaryPalette(QColor(255,255,255, 0));
-    secondaryPalette.setColor(QPalette::Foreground, secondaryColor);
-
+    QPalette secondaryPalette = CommonStatic::GetSecondaryPalette();
     ui->lblPick->setPalette(secondaryPalette);
     ui->lblDisciplines->setPalette(secondaryPalette);
     ui->lblItem->setPalette(secondaryPalette);
@@ -181,7 +175,6 @@ void PlayerCreationWindow::RandomSlot(int random)
             case 2:
                 {
                     Item* i = m_Player->AddItem("Helmet", true);
-                    i->Description = "Adds 2 ENDURANCE points to your total";
                     i->SetEnduranceDelta(2);
                     i->SetIsArmor(true);
                     m_Player->Endurance = m_Player->GetBaseEndurance();
@@ -198,7 +191,6 @@ void PlayerCreationWindow::RandomSlot(int random)
             case 4:
                 {
                     Item* i = m_Player->AddItem("Chainmail Waistcoat", true);
-                    i->Description = "Adds 4 ENDURANCE points to your total";
                     i->SetEnduranceDelta(4);
                     i->SetIsArmor(true);
                     m_Player->Endurance = m_Player->GetBaseEndurance();
