@@ -155,10 +155,10 @@ void ShopWindow::ShowData()
     }
 
     CommonStatic::PopulateBackpackItemsLayout(this, m_Player, ui->layItems,
-                                              SLOT(DropItemSlot()), "Discard",
+                                              SLOT(DropItemSlot()), "Drop",
                                               "", SLOT(SellItemSlot()));
     CommonStatic::PopulateSpecialItemsLayout(this, m_Player, ui->laySpecialItems,
-                                             SLOT(DropItemSlot()), "Discard",
+                                             SLOT(DropItemSlot()), "Drop",
                                              "");
 
     // Reset the sell price:
@@ -238,7 +238,10 @@ bool ShopWindow::DropItem(Item* item)
         item->Unequip();
         m_Player->CheckEndurance();
         m_Player->Items.removeOne(item);
-        delete item;
+        if (m_Section)
+            m_Section->Items.append(item);
+        else
+            delete item;
         return true;
     }
     return false;
@@ -291,7 +294,10 @@ bool ShopWindow::DropWeapon(Weapon* weapon)
         weapon->Unequip();
         m_Player->CheckEndurance();
         m_Player->Items.removeOne(weapon);
-        delete weapon;
+        if (m_Section)
+            m_Section->Items.append(weapon);
+        else
+            delete weapon;
         return true;
     }
     return false;
